import Vue from 'vue';
import VueRouter from 'vue-router';

import Store from '@/store/index';
import APISetting from '@/settings/api';
import Login from '@/views/Login.vue';
import Main from '@/views/Main.vue';
import DietList from '@/views/DietList.vue';
import DietDetail from '@/views/DietDetail.vue';
import ExerciseList from '@/views/ExerciseList.vue';
import ExerciseDetail from '@/views/ExerciseDetail.vue';
import ProgramList from '@/views/ProgramList.vue';
import ProgramCreate from '@/views/ProgramCreate.vue';
import ProgramDetail from '@/views/ProgramDetail.vue';
import ScheduleList from '@/views/ScheduleList.vue';
import ScheduleCreate from '@/views/ScheduleCreate.vue';
import ScheduleDetail from '@/views/ScheduleDetail.vue';
import TraineeList from '@/views/TraineeList.vue';
import TraineeCreate from '@/views/TraineeCreate.vue';
import TraineeDetail from '@/views/TraineeDetail.vue';
import TrainerList from '@/views/TrainerList.vue';
import TrainerCreate from '@/views/TrainerCreate.vue';
import TrainerDetail from '@/views/TrainerDetail.vue';
import VoucherList from '@/views/VoucherList.vue';
import VoucherCreate from '@/views/VoucherCreate.vue';
import VoucherDetail from '@/views/VoucherDetail.vue';


Vue.use(VueRouter);

const routes = [
  {
    path: '/',
    name: 'Login',
    component: Login,
  },
  {
    path: '/main',
    name: 'Main',
    component: Main,
  },
  {
    path: '/diet',
    name: 'DietList',
    component: DietList,
  },
  {
    path: '/diet/:id',
    name: 'DietDetail',
    component: DietDetail,
  },
  {
    path: '/exercise',
    name: 'ExerciseList',
    component: ExerciseList,
  },
  {
    path: '/exercise/:id',
    name: 'ExerciseDetail',
    component: ExerciseDetail,
  },
  {
    path: '/program',
    name: 'ProgramList',
    component: ProgramList,
  },
  {
    path: '/program/create',
    name: 'ProgramCreate',
    component: ProgramCreate,
  },
  {
    path: '/program/:id',
    name: 'ProgramDetail',
    component: ProgramDetail,
  },
  {
    path: '/schedule',
    name: 'ScheduleList',
    component: ScheduleList,
  },
  {
    path: '/schedule/create',
    name: 'ScheduleCreate',
    component: ScheduleCreate,
  },
  {
    path: '/schedule/:id',
    name: 'ScheduleDetail',
    component: ScheduleDetail,
  },
  {
    path: '/trainee',
    name: 'TraineeList',
    component: TraineeList,
  },
  {
    path: '/trainee/create',
    name: 'TraineeCreate',
    component: TraineeCreate,
  },
  {
    path: '/trainee/:id',
    name: 'TraineeDetail',
    component: TraineeDetail,
  },
  {
    path: '/trainer',
    name: 'TrainerList',
    component: TrainerList,
  },
  {
    path: '/trainer/create',
    name: 'TrainerCreate',
    component: TrainerCreate,
  },
  {
    path: '/trainer/:id',
    name: 'TrainerDetail',
    component: TrainerDetail,
  },
  {
    path: '/voucher',
    name: 'VoucherList',
    component: VoucherList,
  },
  {
    path: '/voucher/create',
    name: 'VoucherCreate',
    component: VoucherCreate,
  },
  {
    path: '/voucher/:id',
    name: 'VoucherDetail',
    component: VoucherDetail,
  },
];

const router = new VueRouter({
  mode: 'history',
  base: process.env.BASE_URL,
  routes,
});

router.beforeEach(async (to, from, next) => {
  Store.commit('setPageStartLoading');

  const res = await fetch(APISetting.endpoints.auth.check, APISetting.settings.get);
  if (res.status === 200) {
    const json = await res.json();
    Store.commit('setLogin', json.user);
  } else {
    Store.commit('setLogout');
  }

  next();
});

router.afterEach(() => {
  Store.commit('setPageFinishLoading');
});

export default router;
